==> 1.20.1.tar.gz: viafabricplus/src/main/java/de/florianmichael/viafabricplus/protocolhack/impl/ViaFabricPlusVLViaConfig.java <==
/*
 * This file is part of ViaFabricPlus - https://github.com/FlorianMichael/ViaFabricPlus
 * Copyright (C) 2021-2023 FlorianMichael/EnZaXD and contributors
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package de.florianmichael.viafabricplus.protocolhack.impl;

import de.florianmichael.viafabricplus.base.settings.groups.ExperimentalSettings;
import net.raphimc.vialoader.impl.viaversion.VLViaConfig;

import java.io.File;

public class ViaFabricPlusVLViaConfig extends VLViaConfig {

    public ViaFabricPlusVLViaConfig(File configFile) {
        super(configFile);
    }

    @Override
    public boolean isLeftHandedHandling() {
        return false;
    }

    @Override
    public boolean isShieldBlocking() {
        return false;
    }

    @Override
    public boolean isChunkBorderFix() {
        return ExperimentalSettings.INSTANCE.fixChunkBorders.getValue();
    }

    @Override
    public int get1_13TabCompleteDelay() {
        return 5;
    }
}

==> v2.10.0.tar.gz: viafabricplus/src/main/java/de/florianmichael/viafabricplus/protocolhack/impl/ViaFabricPlusVLViaConfig.java <==
/*
 * This file is part of ViaFabricPlus - https://github.com/FlorianMichael/ViaFabricPlus
 * Copyright (C) 2021-2023 FlorianMichael/EnZaXD and contributors
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package de.florianmichael.viafabricplus.protocolhack.impl;

import de.florianmichael.viafabricplus.settings.impl.ExperimentalSettings;
import net.raphimc.vialoader.impl.viaversion.VLViaConfig;

import java.io.File;

public class ViaFabricPlusVLViaConfig extends VLViaConfig {

    public ViaFabricPlusVLViaConfig(File configFile) {
        super(configFile);
    }

    @Override
    public boolean isLeftHandedHandling() {
        return false;
    }

    @Override
    public boolean isShieldBlocking() {
        return false;
    }

    @Override
    public boolean isChunkBorderFix() {
        return ExperimentalSettings.INSTANCE.fixChunkBorders.getValue();
    }

    @Override
    public int get1_13TabCompleteDelay() {
        return 5;
    }

    @Override
    public boolean isSimulatePlayerTick() {
        return false;
    }
}
